[![GitHub release; latest by date](https://img.shields.io/github/v/release/SETI/rms-solar)](https://github.com/SETI/rms-solar/releases)
[![GitHub Release Date](https://img.shields.io/github/release-date/SETI/rms-solar)](https://github.com/SETI/rms-solar/releases)
[![Test Status](https://img.shields.io/github/actions/workflow/status/SETI/rms-solar/run-tests.yml?branch=main)](https://github.com/SETI/rms-solar/actions)
[![Code coverage](https://img.shields.io/codecov/c/github/SETI/rms-solar/main?logo=codecov)](https://codecov.io/gh/SETI/rms-solar)
<br />
[![PyPI - Version](https://img.shields.io/pypi/v/rms-solar)](https://pypi.org/project/rms-solar)
[![PyPI - Format](https://img.shields.io/pypi/format/rms-solar)](https://pypi.org/project/rms-solar)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/rms-solar)](https://pypi.org/project/rms-solar)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/rms-solar)](https://pypi.org/project/rms-solar)
<br />
[![GitHub commits since latest release](https://img.shields.io/github/commits-since/SETI/rms-solar/latest)](https://github.com/SETI/rms-solar/commits/main/)
[![GitHub commit activity](https://img.shields.io/github/commit-activity/m/SETI/rms-solar)](https://github.com/SETI/rms-solar/commits/main/)
[![GitHub last commit](https://img.shields.io/github/last-commit/SETI/rms-solar)](https://github.com/SETI/rms-solar/commits/main/)
<br />
[![Number of GitHub open issues](https://img.shields.io/github/issues-raw/SETI/rms-solar)](https://github.com/SETI/rms-solar/issues)
[![Number of GitHub closed issues](https://img.shields.io/github/issues-closed-raw/SETI/rms-solar)](https://github.com/SETI/rms-solar/issues)
[![Number of GitHub open pull requests](https://img.shields.io/github/issues-pr-raw/SETI/rms-solar)](https://github.com/SETI/rms-solar/pulls)
[![Number of GitHub closed pull requests](https://img.shields.io/github/issues-pr-closed-raw/SETI/rms-solar)](https://github.com/SETI/rms-solar/pulls)
<br />
![GitHub License](https://img.shields.io/github/license/SETI/rms-solar)
[![Number of GitHub stars](https://img.shields.io/github/stars/SETI/rms-solar)](https://github.com/SETI/rms-solar/stargazers)
![GitHub forks](https://img.shields.io/github/forks/SETI/rms-solar)

# rms-solar

Supported versions: Python >= 3.8

# PDS Ring-Moon Systems Node, SETI Institute
# solar Library
